Template View
=============

.. automodule:: pyramid_views.views.base

    .. autoclass:: TemplateView

        .. autoattribute:: template_name
        .. autoattribute:: content_type
        .. automethod:: get_context_data
        .. autoattribute:: macro_names
        .. automethod:: get_macro_names
        .. automethod:: get

